"""
Descriptive HTTP status codes, for code readability.

See RFC 2616 - http://www.w3.org/Protocols/rfc2616/rfc2616-sec10.html
And RFC 6585 - http://tools.ietf.org/html/rfc6585
"""
from __future__ import unicode_literals


def is_informational(code):
    return code >= 100 and code <= 199


def is_success(code):
    return code >= 200 and code <= 299


def is_redirect(code):
    return code >= 300 and code <= 399


def is_client_error(code):
    return code >= 400 and code <= 499


def is_server_error(code):
    return code >= 500 and code <= 599


"""
Statuses
"""
HTTP_100_CONTINUE = 100
HTTP_101_SWITCHING_PROTOCOLS = 101
HTTP_200_OK = 200
HTTP_201_CREATED = 201
HTTP_202_ACCEPTED = 202
HTTP_203_NON_AUTHORITATIVE_INFORMATION = 203
HTTP_204_NO_CONTENT = 204
HTTP_205_RESET_CONTENT = 205
HTTP_206_PARTIAL_CONTENT = 206
HTTP_300_MULTIPLE_CHOICES = 300
HTTP_301_MOVED_PERMANENTLY = 301
HTTP_302_FOUND = 302
HTTP_303_SEE_OTHER = 303
HTTP_304_NOT_MODIFIED = 304
HTTP_305_USE_PROXY = 305
HTTP_306_RESERVED = 306
HTTP_307_TEMPORARY_REDIRECT = 307
HTTP_400_BAD_REQUEST = 400
HTTP_401_UNAUTHORIZED = 401
HTTP_402_PAYMENT_REQUIRED = 402
HTTP_403_FORBIDDEN = 403
HTTP_404_NOT_FOUND = 404
HTTP_405_METHOD_NOT_ALLOWED = 405
HTTP_406_NOT_ACCEPTABLE = 406
HTTP_407_PROXY_AUTHENTICATION_REQUIRED = 407
HTTP_408_REQUEST_TIMEOUT = 408
HTTP_409_CONFLICT = 409
HTTP_410_GONE = 410
HTTP_411_LENGTH_REQUIRED = 411
HTTP_412_PRECONDITION_FAILED = 412
HTTP_413_REQUEST_ENTITY_TOO_LARGE = 413
HTTP_414_REQUEST_URI_TOO_LONG = 414
HTTP_415_UNSUPPORTED_MEDIA_TYPE = 415
HTTP_416_REQUESTED_RANGE_NOT_SATISFIABLE = 416
HTTP_417_EXPECTATION_FAILED = 417
HTTP_428_PRECONDITION_REQUIRED = 428
HTTP_429_TOO_MANY_REQUESTS = 429
HTTP_431_REQUEST_HEADER_FIELDS_TOO_LARGE = 431
HTTP_451_UNAVAILABLE_FOR_LEGAL_REASONS = 451
HTTP_500_INTERNAL_SERVER_ERROR = 500
HTTP_501_NOT_IMPLEMENTED = 501
HTTP_502_BAD_GATEWAY = 502
HTTP_503_SERVICE_UNAVAILABLE = 503
HTTP_504_GATEWAY_TIMEOUT = 504
HTTP_505_HTTP_VERSION_NOT_SUPPORTED = 505
HTTP_511_NETWORK_AUTHENTICATION_REQUIRED = 511


"""
Status messages
"""
msg = {
    '100': 'CONTINUE',
    '101': 'SWITCHING_PROTOCOLS',
    '200': 'OK',
    '201': 'CREATED',
    '202': 'ACCEPTED',
    '203': 'NON_AUTHORITATIVE_INFORMATION',
    '204': 'NO_CONTENT',
    '205': 'RESET_CONTENT',
    '206': 'PARTIAL_CONTENT',
    '300': 'MULTIPLE_CHOICES',
    '301': 'MOVED_PERMANENTLY',
    '302': 'FOUND',
    '303': 'SEE_OTHER',
    '304': 'NOT_MODIFIED',
    '305': 'USE_PROXY',
    '306': 'RESERVED',
    '307': 'TEMPORARY_REDIRECT',
    '400': 'BAD_REQUEST',
    '401': 'UNAUTHORIZED',
    '402': 'PAYMENT_REQUIRED',
    '403': 'FORBIDDEN',
    '404': 'NOT_FOUND',
    '405': 'METHOD_NOT_ALLOWED',
    '406': 'NOT_ACCEPTABLE',
    '407': 'PROXY_AUTHENTICATION_REQUIRED',
    '408': 'REQUEST_TIMEOUT',
    '409': 'CONFLICT',
    '410': 'GONE',
    '411': 'LENGTH_REQUIRED',
    '412': 'PRECONDITION_FAILED',
    '413': 'REQUEST_ENTITY_TOO_LARGE',
    '414': 'REQUEST_URI_TOO_LONG',
    '415': 'UNSUPPORTED_MEDIA_TYPE',
    '416': 'REQUESTED_RANGE_NOT_SATISFIABLE',
    '417': 'EXPECTATION_FAILED',
    '428': 'PRECONDITION_REQUIRED',
    '429': 'TOO_MANY_REQUESTS',
    '431': 'REQUEST_HEADER_FIELDS_TOO_LARGE',
    '451': 'UNAVAILABLE_FOR_LEGAL_REASONS',
    '500': 'INTERNAL_SERVER_ERROR',
    '501': 'NOT_IMPLEMENTED',
    '502': 'BAD_GATEWAY',
    '503': 'SERVICE_UNAVAILABLE',
    '504': 'GATEWAY_TIMEOUT',
    '505': 'HTTP_VERSION_NOT_SUPPORTED',
    '511': 'NETWORK_AUTHENTICATION_REQUIRED',
}